@@ -237,7 +237,7 @@ class CivInfoTransientCache(val civInfo: Civilization) {
             for (unique in civInfo.getTriggeredUniques(UniqueType.TriggerUponDiscoveringNaturalWonder,
                 StateForConditionals(civInfo, tile = tile)
             ))
-                UniqueTriggerActivation.triggerCivwideUnique(unique, civInfo, tile=tile, triggerNotificationText = "due to discovering a Natural Wonder")
+                UniqueTriggerActivation.triggerUnique(unique, civInfo, tile=tile, triggerNotificationText = "due to discovering a Natural Wonder")
         }
     }
 
@@ -282,7 +282,7 @@ class CivInfoTransientCache(val civInfo: Civilization) {
 
     fun updateCivResources() {
         val newDetailedCivResources = ResourceSupplyList()
-        for (city in civInfo.cities) newDetailedCivResources.add(city.getCityResources())
+        for (city in civInfo.cities) newDetailedCivResources.add(city.getResourcesGeneratedByCity())
 
         if (!civInfo.isCityState()) {
             // First we get all these resources of each city state separately
